@@ -22,9 +22,7 @@ import locale
 import math
 import optparse
 import os
-import pwd
 import select
-import struct
 import sys
 import time
 
@@ -64,7 +62,7 @@ def format_stats(options, process, duration):
     # Keep in sync with TaskStatsNetlink.members_offsets and
     # IOTopUI.get_data(self)
     def delay2percent(delay): # delay in ns, duration in s
-        return '%.2f' % min(99.99, delay / (duration * 10000000.0))
+        return '%.2f %%' % min(99.99, delay / (duration * 10000000.0))
     if options.accumulated:
         stats = process.stats_accum
         display_format = lambda size, duration: format_size(options, size)
@@ -364,25 +362,23 @@ class IOTopUI(object):
             stats = format_stats(self.options, p, self.process_list.duration)
             io_delay, swapin_delay, read_bytes, write_bytes = stats
             if Stats.has_blkio_delay_total:
-                delay_stats = '%7s %7s' % (swapin_delay, io_delay)
+                delay_stats = '%7s %7s ' % (swapin_delay, io_delay)
             else:
                 delay_stats = ' ?unavailable?  '
+            line = '%5d %4s %-8s %11s %11s %s' % (
+                p.pid, p.get_ioprio(), p.get_user()[:8], read_bytes,
+                write_bytes, delay_stats)
             cmdline = p.get_cmdline()
             if not self.options.batch:
-                line = ' %10s %10s %s' % (
-                   read_bytes, write_bytes, delay_stats)
-                if (len(line) > self.width - 12):
-                    line = ' %10s %10s' % (
-                    read_bytes, write_bytes)
-                cmd_len = self.width - len(line) - 7 
-                if 2 < cmd_len < len(cmdline):
-                    len1 = (cmd_len - 1) // 2
-                    offset2 = -(cmd_len - len1 - 1)
+                remaining_length = self.width - len(line)
+                if 2 < remaining_length < len(cmdline):
+                    len1 = (remaining_length - 1) // 2
+                    offset2 = -(remaining_length - len1 - 1)
                     cmdline = cmdline[:len1] + '~' + cmdline[offset2:]
-                line1 = '%5d %s %s' % (
-                      p.pid, cmdline.rjust(cmd_len), line)
-                line1 = line1[:self.width]
-            return line1
+            line += cmdline
+            if not self.options.batch:
+                line = line[:self.width]
+            return line
 
         def should_format(p):
             return not self.options.only or \
@@ -402,22 +398,20 @@ class IOTopUI(object):
 
     def refresh_display(self, first_time, total_read, total_write, duration):
         summary = 'Total DISK READ: %s | Total DISK WRITE: %s' % (
-                          format_bandwidth(self.options, total_read, duration),
-                          format_bandwidth(self.options, total_write, duration))
+                format_bandwidth(self.options, total_read, duration).rjust(14),
+                format_bandwidth(self.options, total_write, duration).rjust(14))
         if self.options.processes:
             pid = '  PID'
         else:
             pid = '  TID'
+        titles = [pid, '  PRIO', '  USER', '     DISK READ', '  DISK WRITE',
+                  '  SWAPIN', '      IO', '    COMMAND']
         lines = self.get_data()
-        if (self.width > 50): # empirical value for osso-xterm
-                titles = [pid, 'COMMAND'.rjust(self.width - 44), '      READ', '      WRITE',
-                    '      SWAP', '     IO']
-        else:
-                titles = [pid, 'COMMAND'.rjust(self.width - 28), '      READ', '      WRITE']
         if self.options.time:
             titles = ['    TIME'] + titles
             current_time = time.strftime('%H:%M:%S ')
             lines = [current_time + l for l in lines]
+            summary = current_time + summary
         if self.options.batch:
             if self.options.quiet <= 2:
                 print summary
@@ -464,10 +458,19 @@ def run_iotop_window(win, options):
     ui.run()
 
 def run_iotop(options):
-    if options.batch:
-        return run_iotop_window(None, options)
-    else:
-        return curses.wrapper(run_iotop_window, options)
+    try:
+        if options.batch:
+            return run_iotop_window(None, options)
+        else:
+            return curses.wrapper(run_iotop_window, options)
+    except OSError, e:
+        if e.errno == errno.EPERM:
+            print >> sys.stderr, e
+            print >> sys.stderr, ('iotop requires root or the NET_ADMIN '
+                                  'capability.')
+            sys.exit(1)
+        else:
+            raise
 
 #
 # Profiling
